@@ -50,9 +50,12 @@ sub day_name            { $_[0]->day_names->        [ $_[1]->day_of_week_0 ] }
 sub day_abbreviation    { $_[0]->day_abbreviations->[ $_[1]->day_of_week_0 ] }
 sub day_narrow          { $_[0]->day_narrows->      [ $_[1]->day_of_week_0 ] }
 
+sub quarter_name         { $_[0]->quarter_names->        [ $_[1]->quarter - 1 ] }
+sub quarter_abbreviation { $_[0]->quarter_abbreviations->[ $_[1]->quarter - 1 ] }
+
 sub am_pm               { $_[0]->am_pms->[ $_[1]->hour < 12 ? 0 : 1 ] }
 
-sub era                 { $_[0]->eras->[ $_[1]->ce_year < 0 ? 0 : 1 ] }
+sub era                 { $_[0]->era_abbreviations->[ $_[1]->ce_year < 0 ? 0 : 1 ] }
 
 sub default_date_format
 {
@@ -107,6 +110,9 @@ sub set_default_time_format_length
     $self->{default_time_format_length} = lc $l;
 }
 
+# Backwards compatibility
+sub eras                { $_[0]->era_abbreviations }
+
 sub STORABLE_freeze
 {
     my $self = shift;
@@ -114,6 +120,16 @@ sub STORABLE_freeze
     return $self->id;
 }
 
+
+sub STORABLE_attach
+{
+    my $class = shift;
+    my $cloning = shift;
+    my $serialized = shift;
+
+    return DateTime::Locale->load( $serialized );
+}
+
 sub STORABLE_thaw
 {
     my $self = shift;
@@ -123,6 +139,8 @@ sub STORABLE_thaw
     my $obj = DateTime::Locale->load( $serialized );
 
     %$self = %$obj;
+
+    return $self;
 }
 
 
@@ -194,10 +212,15 @@ names, and need not be unique.
 Returns an array reference containing the localized forms of "AM" and
 "PM".
 
-=item * eras
+=item * era_abbreviations
 
-Returns an array reference containing the localized forms of "BCE" and
-"CE".
+Returns an array reference containing the localized forms of the
+abbreviation for the eras, such as "BCE" and "CE".
+
+=item * era_names
+
+Returns an array reference containing the localized forms the name of
+the eras, such as "Before Common Era" and "Common Era".
 
 =item * long_date_format, full_date_format, medium_date_format, short_date_format
 
